# Loading required libraries
require(xlsx)
require(psych)
require(nlme)

sink("output.txt")
sessionInfo()

# Loading data (do not forget to set your working directory with setwd())
QD <- read.xlsx("Questionnaire.xlsx", 1)
Behavioral <- read.xlsx("Behavioral.xlsx", 1)

# During this analysis we use the following abbreviations:
# Frnd refers to friendship, Ind to Independence, and Fam to family security
# Usa refers to usability, Tru to trust, Lik for liking, Dom for dominance, and Int for intimacy
# Items preceded with N refer to the basic app, BA (i.e. commitments menu *N*ot available)
# Items preceded with A refer to the socially adaptive electronic partner, SAEP (i.e. commitments menu *A*vailable)

# Table 1: internal reliability analysis before removing any items

# Reversing questionnaire items with a inverted scale
N9r = 10-QD$N9
N10r = 10-QD$N10
N11r = 10-QD$N11
N12r = 10-QD$N12
N13r = 10-QD$N13
N14r = 10-QD$N14

A9r = 10-QD$A9
A10r = 10-QD$A10
A11r = 10-QD$A11
A12r = 10-QD$A12
A13r = 10-QD$A13
A14r = 10-QD$A14

NInd_Rel <- data.frame(QD$N1, QD$N5, QD$N7, QD$N15, QD$N16, QD$N17, N9r, N10r, N11r, N12r, N14r)
AInd_Rel <- data.frame(QD$A1, QD$A5, QD$A7, QD$A15, QD$A16, QD$A17, A9r, A10r, A11r, A12r, A14r)

alpha(NInd_Rel)
alpha(AInd_Rel)

NFrnd_Rel <- data.frame(QD$N1, QD$N2, QD$N3, QD$N4, QD$N5, QD$N6, QD$N19)
AFrnd_Rel <- data.frame(QD$A1, QD$A2, QD$A3, QD$A4, QD$A5, QD$A6, QD$A19)

alpha(NFrnd_Rel)
alpha(AFrnd_Rel)

NTru_Rel <- data.frame(QD$N26, QD$N27, QD$N28, QD$N29, QD$N30)
ATru_Rel <- data.frame(QD$A26, QD$A27, QD$A28, QD$A29, QD$A30)

alpha(NTru_Rel)
alpha(ATru_Rel)

# Table 2: Iteratively removing items one by one, based on calculated reliability if an item is dropped
# Until satisfactory alpha is reached

NInd_Rel <- data.frame(QD$N1, QD$N5, QD$N7, QD$N15, QD$N16, QD$N17, N9r, N10r, N11r, N12r, N14r)
alpha(NInd_Rel)

NInd_Rel10 <- data.frame(QD$N1, QD$N5, QD$N7, QD$N15, QD$N16, QD$N17, N9r, N10r, N11r, N14r)
alpha(NInd_Rel10)

NInd_Rel9 <- data.frame(QD$N1, QD$N5, QD$N7, QD$N15, QD$N16, QD$N17, N9r, N10r, N11r)
alpha(NInd_Rel9)

NInd_Rel8 <- data.frame(QD$N1, QD$N5, QD$N7, QD$N15, QD$N16, QD$N17, N9r, N10r)
alpha(NInd_Rel8)

NInd_Rel7 <- data.frame(QD$N1, QD$N5, QD$N7, QD$N16, QD$N17, N9r, N10r)
alpha(NInd_Rel7)

AInd_Rel7 <- data.frame(QD$A1, QD$A5, QD$A7, QD$A16, QD$A17, A9r, A10r)
alpha(AInd_Rel7)


NTru_Rel <- data.frame(QD$N26, QD$N27, QD$N28, QD$N29, QD$N30)
alpha(NTru_Rel)

ATru_Rel <- data.frame(QD$A26, QD$A27, QD$A28, QD$A29, QD$A30)
alpha(ATru_Rel)

ATru_Rel4 <- data.frame(QD$A26, QD$A27, QD$A29, QD$A30)
alpha(ATru_Rel4)

ATru_Rel3 <- data.frame(QD$A27, QD$A29, QD$A30)
alpha(ATru_Rel3)

NTru_Rel3 <- data.frame(QD$N27, QD$N29, QD$N30)
alpha(NTru_Rel3)

# Table 3: Mean and SD for individual values, for the app in general, i.e. average of BA and SAEP

# Constructing values raw questionnaire items

NInd7 <- (QD$N1 + QD$N5 + QD$N7 + QD$N16 + QD$N17 + (10-QD$N9) + (10-QD$N10))/7
AInd7 <- (QD$A1 + QD$A5 + QD$A7 + QD$A16 + QD$A17 + (10-QD$A9) + (10-QD$A10))/7
NFrnd <- (QD$N1 + QD$N2 + QD$N3 + QD$N4 + QD$N5 + QD$N6 + QD$N19)/7
AFrnd <- (QD$A1 + QD$A2 + QD$A3 + QD$A4 + QD$A5 + QD$A6 + QD$A19)/7
NFam1 <- 10-QD$N13
AFam1 <- 10-QD$A13
NFam2 <- QD$N18
AFam2 <- QD$A18

Ind7 <- (NInd7+AInd7)/2
Frnd <- (NFrnd+AFrnd)/2
Fam1 <- (NFam1+AFam1)/2
Fam2 <- (NFam2+AFam2)/2

# Independent t-tests
mean(Frnd, na.rm=TRUE); sd(Frnd, na.rm=TRUE)
mean(Ind7, na.rm=TRUE); sd(Ind7, na.rm=TRUE)
mean(Fam1, na.rm=TRUE); sd(Fam1, na.rm=TRUE)
mean(Fam2, na.rm=TRUE); sd(Fam2, na.rm=TRUE)

t.test(Frnd,mu=5)
t.test(Ind7,mu=5)
t.test(Fam,mu=5)
t.test(Fam1,mu=5)
t.test(Fam2,mu=5)

# Table 4: Mean and SD for usability and social actorship, for the app in general, i.e. average of BA and SAEP

# Constructing usability and social actorship items from raw questionnaire items
NUsa <- (QD$N20 + QD$N21)/2
AUsa <- (QD$A20 + QD$A21)/2
NLike <- (QD$N22 + QD$N23 + QD$N24)/3
ALike <- (QD$A22 + QD$A23 + QD$A24)/3
NDom <- QD$N25
ADom <- QD$A25
NTru3 <- (QD$N27 + QD$N29 + QD$N30)/3
ATru3 <- (QD$A27 + QD$N29 + QD$N30)/3
NInt <- QD$N31
AInt <- QD$A31

Usa <- (NUsa+AUsa)/2
Like <- (NLike+ALike)/2
Dom <- (NDom+ADom)/2
Tru3 <- (NTru3+ATru3)/2
Int <- (NInt+AInt)/2

# Mean, SD, and independent t-tests
mean(Usa, na.rm=TRUE); sd(Usa, na.rm=TRUE)
mean(Like, na.rm=TRUE); sd(Like, na.rm=TRUE)
mean(Dom, na.rm=TRUE); sd(Dom, na.rm=TRUE)
mean(Tru3, na.rm=TRUE); sd(Tru3, na.rm=TRUE)
mean(Int, na.rm=TRUE); sd(Int, na.rm=TRUE)

t.test(Usa,mu=5)
t.test(Like,mu=5)
t.test(Dom,mu=5)
t.test(Tru3,mu=5)
t.test(Int,mu=5)

# Table 5: Mean and SD for individual values, for each of the two versions
mean(NFrnd, na.rm=TRUE); sd(NFrnd, na.rm=TRUE)
mean(NInd7, na.rm=TRUE); sd(NInd7, na.rm=TRUE)
mean(NFam1, na.rm=TRUE); sd(NFam1, na.rm=TRUE)
mean(NFam2, na.rm=TRUE); sd(NFam2, na.rm=TRUE)

mean(AFrnd, na.rm=TRUE); sd(AFrnd, na.rm=TRUE)
mean(AInd7, na.rm=TRUE); sd(AInd7, na.rm=TRUE)
mean(AFam1, na.rm=TRUE); sd(AFam1, na.rm=TRUE)
mean(AFam2, na.rm=TRUE); sd(AFam2, na.rm=TRUE)

# Paired t-tests
t.test(NFrnd,AFrnd,paired=TRUE)
t.test(NInd7,AInd7,paired=TRUE)
t.test(NFam,AFam,paired=TRUE)
t.test(NFam1,AFam1,paired=TRUE)
t.test(NFam2,AFam2,paired=TRUE)

# Table 6: Mean and SD for individual values, for each of the two versions
mean(NUsa, na.rm=TRUE); sd(NUsa, na.rm=TRUE)
mean(NLike, na.rm=TRUE); sd(NLike, na.rm=TRUE)
mean(NDom, na.rm=TRUE); sd(NDom, na.rm=TRUE)
mean(NTru3, na.rm=TRUE); sd(NTru3, na.rm=TRUE)
mean(NInt, na.rm=TRUE); sd(NInt, na.rm=TRUE)

mean(AUsa, na.rm=TRUE); sd(AUsa, na.rm=TRUE)
mean(ALike, na.rm=TRUE); sd(ALike, na.rm=TRUE)
mean(ADom, na.rm=TRUE); sd(ADom, na.rm=TRUE)
mean(ATru3, na.rm=TRUE); sd(ATru3, na.rm=TRUE)
mean(AInt, na.rm=TRUE); sd(AInt, na.rm=TRUE)

# Paired t-tests
t.test(NUsa,AUsa,paired=TRUE)
t.test(NLike,ALike,paired=TRUE)
t.test(NTru3,ATru3,paired=TRUE)
t.test(NDom,ADom,paired=TRUE)
t.test(NInt,AInt,paired=TRUE)

# Table 7: behavioral sampling, and the subsequent LME model analysis

table(Behavioral$emo.type, Behavioral$version)

# Data preparation
Behavioral$version = as.factor(Behavioral$version)
Behavioral$pp = as.factor(Behavioral$pp)
Behavioral$BSO = as.factor(Behavioral$BSO)

# Baseline model
lme0 <-lme(emo.type ~1, random =~1|BSO/pp, data = Behavioral, correlation = corAR1(form=~1|BSO/pp), method ="ML")
summary(lme0)

# Model with version as a fixed factor
lme1 <-lme(emo.type ~ version, random =~1|BSO/pp, data = Behavioral, correlation = corAR1(form=~1|BSO/pp), method ="ML")
anova(lme0,lme1)

# R squared

# Calculating variances
vc.lme0 <- VarCorr(lme0)
sigma0 <-lme0$sigma
tau0 <- as.numeric(vc.lme0[4,2])
sigma0SQ <- sigma0 * sigma0
tau0SQ <- tau0 * tau0

vc.lme1 <- VarCorr(lme1)
sigma1 <-lme1$sigma
tau1 <- as.numeric(vc.lme1[4,2])
sigma1SQ <- sigma1 * sigma1
tau1SQ <- tau1 * tau1

Rsquare <- 1 - ((sigma1SQ + tau1SQ) / (sigma0SQ + tau0SQ))
Rsquare

######### stop redireting output.
sink()

cat("\n\nOutput of the analysis can be found back in file output.txt")